import React from "react";
import styled from "styled-components";
import ms from "pretty-ms";
import LobbyPlayerList from "./LobbyPlayerList";
import HeaderAndFooter from "../../util/HeaderAndFooter";
import ClickToCopy from "../../util/ClickToCopy";
import { useGameJoined, useGameId } from "../../../domain/gameStore";
import JoinForm from "./JoinForm";
import StartGame from "./StartGame";
import useGameInfo from "../../../hooks/useGameInfo";
import Loading from "../../util/Loading";

const InfoContainer = styled.div`
  flex: 3;
  align-self: center;

  display: flex;
  flex-flow: column nowrap;
  justify-content: space-around;
  align-items: center;
  height: 100%;
`

const PageContainer = styled.div`
  flex: 1;
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-between;
  align-items: flex-start;
`

const Label = styled.span`
  padding: 1em;
  text-align: center;
`

const getUrl = gameId => {
  const u = new URL(window.location.href);
  u.searchParams.append("join", gameId);
  return u.href;
}

const Lobby = ({ onStart }) => {
  const gameId = useGameId();
  const joined = useGameJoined();
  const { players, rounds, timer } = useGameInfo();

  if (!players || !rounds || !timer) {
    return <Loading/>
  }

  return (
    <HeaderAndFooter>
      <PageContainer>
        <InfoContainer>
          <Label>Game will run for {rounds} rounds, each with a {ms(timer * 1000)} time limit</Label>
          {
            joined
              ? <StartGame onStart={onStart}/>
              : <JoinForm />
          }
          <Label><ClickToCopy text={getUrl(gameId)}>Click here to copy an invite link!</ClickToCopy></Label>
        </InfoContainer>
        <LobbyPlayerList playerNames={players?.map(({ name }) => name) ?? []} />
      </PageContainer>
    </HeaderAndFooter>
  )
};

export default Lobby;
